@@ -6,47 +6,45 @@
 #' See Details.
 #' @param year (numeric) One of the years from 1842 to 2014
 #' @param overwrite (logical) To overwrite the path to store files in or not,
-#' Default: \code{TRUE}
+#' Default: `TRUE`
 #' @param what (character) One of storm_columns or storm_names.
 #' @param type (character) One of points or lines. This gives shp files with
 #' points, or with lines.
 #' @param x Output from \code{storm_shp}, a path to shp file to read in.
-#' @param ... Curl options passed on to \code{\link[crul]{HttpClient}} 
-#' (optional)
+#' @param ... Curl options passed on to [crul::verb-GET] (optional)
 #'
 #' @return A tibble (data.frame)
 #'
 #' @details International Best Track Archive for Climate Stewardship (IBTrACS)
 #'
 #' Details for storm serial numbers:
-#' \itemize{
-#'  \item YYYY is the corresponding year of the first recorded observation of
+#' 
+#' - YYYY is the corresponding year of the first recorded observation of
 #'  the storm
-#'  \item JJJ is the day of year of the first recorded observation of the storm
-#'  \item H is the hemisphere of the storm: N=Northern, S=Southern
-#'  \item TT is the absolute value of the rounded latitude of the first
+#' - JJJ is the day of year of the first recorded observation of the storm
+#' - H is the hemisphere of the storm: N=Northern, S=Southern
+#' - TT is the absolute value of the rounded latitude of the first
 #'  recorded observation of the storm (range 0-90, if basin=SA or SH, then TT
 #'  in reality is negative)
-#'  \item NNN is the rounded longitude of the first recorded observation of
+#' - NNN is the rounded longitude of the first recorded observation of
 #'  the storm (range 0-359)
-#' }
 #'
-#' For example: \code{1970143N19091} is a storm in the North Atlantic which
+#' For example: `1970143N19091` is a storm in the North Atlantic which
 #' started on May 23, 1970 near 19N 91E
 #'
-#' See \url{http://www.ncdc.noaa.gov/ibtracs/index.php?name=numbering} for more
+#' See <http://www.ncdc.noaa.gov/ibtracs/index.php?name=numbering> for more
 #'
-#' The datasets included in the package \code{\link{storm_names}}, and
-#' \code{\link{storm_columns}} may help in using these storm functions.
+#' The datasets included in the package [storm_names()], and
+#' [storm_columns()] may help in using these storm functions.
 #'
 #'
 #' @section File storage:
 #' We use \pkg{rappdirs} to store files, see
-#' \code{\link[rappdirs]{user_cache_dir}} for how
+#' [rappdirs::user_cache_dir()] for how
 #' we determine the directory on your machine to save files to, and run
-#' \code{rappdirs::user_cache_dir("rnoaa/storms")} to get that directory.
+#' `rappdirs::user_cache_dir("rnoaa/storms")` to get that directory.
 #'
-#' @references \url{http://www.ncdc.noaa.gov/ibtracs/index.php?name=wmo-data}
+#' @references <http://www.ncdc.noaa.gov/ibtracs/index.php?name=wmo-data>
 #'
 #' @examples \dontrun{
 #' # Metadata
@@ -107,7 +105,7 @@ storm_data <- function(basin = NULL, storm = NULL, year = NULL,
     csvpath <- storm_GET(path, basin, storm, year, overwrite, ...)
   }
   message(sprintf("<path>%s", csvpath), "\n")
-  tibble::as_data_frame(read_csv(csvpath))
+  tibble::as_tibble(read_csv(csvpath))
 }
 
 storm_GET <- function(bp, basin, storm, year, overwrite, ...){
