@@ -2,6 +2,8 @@ context("check_response")
 
 test_that("check_response returns an error", {
   skip_on_cran()
+  skip_on_travis()
+  skip_on_appveyor()
   skip_if_government_down()
 
   # Sys.sleep(time = 0.5)
@@ -21,6 +23,8 @@ test_that("check_response returns an error", {
 
 test_that("check_response returns the correct error messages", {
   skip_on_cran()
+  skip_on_travis()
+  skip_on_appveyor()
   skip_if_government_down()
   
   # no data found
